firewall {
    all-ping enable
    broadcast-ping disable
    group {
        network-group BOGONS {
            description "Invalid WAN networks"
            network 10.0.0.0/8
            network 100.64.0.0/10
            network 127.0.0.0/8
            network 169.254.0.0/16
            network 172.16.0.0/12
            network 192.0.0.0/24
            network 192.0.2.0/24
            network 192.168.0.0/16
            network 198.18.0.0/15
            network 198.51.100.0/24
            network 203.0.113.0/24
            network 224.0.0.0/3
        }
        network-group DMZ-Subnet {
            description "DMZ Subnet"
            network 192.168.200.0/24
        }
        network-group LAN-Subnet {
            description "LAN Subnet"
            network 192.168.1.0/24
        }
    }
    ipv6-receive-redirects disable
    ipv6-src-route disable
    ip-src-route disable
    log-martians disable
    name DMZ-LAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
    }
    name DMZ-LOCAL {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
        rule 400 {
            action accept
            description NNTP
            destination {
                port 123
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
        rule 600 {
            action accept
            description DNS
            destination {
                port 53
            }
            log enable
            protocol tcp_udp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
        rule 700 {
            action accept
            description DHCP
            destination {
                port 67,68
            }
            log enable
            protocol udp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
    }
    name DMZ-WAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
        rule 200 {
            action accept
            description TCP80/TCP443
            destination {
                port 80,443
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
        rule 300 {
            action accept
            description FTP
            destination {
                port 20,21
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
        rule 500 {
            action accept
            description "TEST Rule SMTP"
            destination {
                port 25
            }
            log enable
            protocol tcp
            source {
                address 192.168.200.200
            }
        }
        rule 600 {
            action accept
            description "TEST Rule DNS extern"
            destination {
                port 53
            }
            log enable
            protocol tcp_udp
            source {
                address 192.168.200.200
            }
        }
        rule 800 {
            action accept
            description SSH
            destination {
                port 22
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group DMZ-Subnet
                }
            }
        }
    }
    name LAN-DMZ {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
        rule 200 {
            action accept
            description "TEST Rule TCP80/TCP443"
            destination {
                port 80,443
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 800 {
            action accept
            description "TEST Rule TCP22"
            destination {
                port 22
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 900 {
            action accept
            description "TEST Rule TCP993"
            destination {
                address 192.168.200.200
                port 993
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
    }
    name LAN-LOCAL {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            description ICMP
            log enable
            protocol icmp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 400 {
            action accept
            description NNTP
            destination {
                port 123
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 600 {
            action accept
            description DNS
            destination {
                port 53
            }
            log enable
            protocol tcp_udp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 700 {
            action accept
            description DHCP
            destination {
                port 67,68
            }
            log enable
            protocol udp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 800 {
            action accept
            description SSH
            destination {
                port 22
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 801 {
            action accept
            description HTTPS
            destination {
                port 443
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 802 {
            action accept
            description NtopNG
            destination {
                port 3000
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
    }
    name LAN-WAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 3 {
            action accept
            log enable
            protocol icmp
        }
        rule 4 {
            action accept
            description TCP80/TCP443
            destination {
                port 80,443
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 5 {
            action accept
            description FTP
            destination {
                port 20,21
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 6 {
            action accept
            description SSH
            destination {
                port 22
            }
            log enable
            protocol tcp
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
        rule 7 {
            action accept
            description "Allow All"
            log disable
            source {
                group {
                    network-group LAN-Subnet
                }
            }
        }
    }
    name LOCAL-DMZ {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
        rule 500 {
            action accept
            destination {
                address 192.168.200.200
                port 25
            }
            log enable
            protocol tcp
        }
        rule 600 {
            action accept
            destination {
                address 192.168.200.200
                port 53
            }
            log enable
            protocol tcp_udp
        }
        rule 700 {
            action accept
            destination {
                group {
                    network-group DMZ-Subnet
                }
                port 67,68
            }
            log enable
            protocol udp
        }
    }
    name LOCAL-LAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 100 {
            action accept
            log enable
            protocol icmp
        }
        rule 700 {
            action accept
            description DHCP
            destination {
                group {
                    network-group LAN-Subnet
                }
                port 67,68
            }
            log enable
            protocol udp
        }
        rule 701 {
            action accept
            description DNS
            destination {
                group {
                    network-group LAN-Subnet
                }
                port 53
            }
            log enable
            protocol udp
        }
    }
    name LOCAL-WAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 3 {
            action accept
            log enable
            protocol icmp
        }
        rule 4 {
            action accept
            description FTP
            destination {
                port 20,21
            }
            log enable
            protocol tcp
        }
        rule 5 {
            action accept
            description SMTP
            destination {
                port 25
            }
            log enable
            protocol tcp
        }
        rule 6 {
            action accept
            description SSH
            destination {
                port 22
            }
            log enable
            protocol tcp
        }
        rule 7 {
            action accept
            description DNS
            destination {
                port 53
            }
            log enable
            protocol tcp_udp
        }
        rule 8 {
            action accept
            description NTP
            destination {
                port 123
            }
            log enable
            protocol tcp
        }
        rule 9 {
            action accept
            description HTTP/S
            destination {
                port 80,443
            }
            log enable
            protocol tcp
        }
    }
    name WAN-DMZ {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            description "Drop BOGONS"
            log disable
            protocol all
            source {
                group {
                    network-group BOGONS
                }
            }
        }
        rule 3 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 4 {
            action accept
            destination {
                address 192.168.200.200
                port 25
            }
            log enable
            protocol tcp
        }
        rule 5 {
            action accept
            destination {
                address 192.168.200.200
                port 53
            }
            log enable
            protocol tcp_udp
        }
    }
    name WAN-LAN {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            description "Drop BOGONS"
            log disable
            protocol all
            source {
                group {
                    network-group BOGONS
                }
            }
        }
        rule 3 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
    }
    name WAN-LOCAL {
        default-action drop
        enable-default-log
        rule 1 {
            action accept
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            description "Drop BOGONS"
            log disable
            protocol all
            source {
                group {
                    network-group BOGONS
                }
            }
        }
        rule 3 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 4 {
            action accept
            log enable
            protocol icmp
        }
    }
    receive-redirects disable
    send-redirects enable
    source-validation disable
    syn-cookies enable
}
interfaces {
    ethernet eth0 {
        address dhcp
        description WAN
        duplex auto
        speed auto
    }
    ethernet eth1 {
        address 192.168.1.1/24
        description LAN
        duplex auto
        speed auto
    }
    ethernet eth2 {
        address 192.168.200.1/24
        description DMZ
        duplex auto
        speed auto
    }
    loopback lo {
    }
}
port-forward {
    auto-firewall enable
    hairpin-nat enable
    lan-interface eth1
    lan-interface eth2
    wan-interface eth0
}
service {
    dhcp-server {
        disabled false
        hostfile-update disable
        shared-network-name DHCP-DMZ {
            authoritative enable
            description "DHCP DMZ"
            subnet 192.168.200.0/24 {
                default-router 192.168.200.1
                dns-server 192.168.200.1
                lease 86400
                start 192.168.200.50 {
                    stop 192.168.200.149
                }
            }
        }
        shared-network-name DHCP-LAN {
            authoritative enable
            description "DHCP LAN"
            subnet 192.168.1.0/24 {
                default-router 192.168.1.1
                dns-server 192.168.1.1
                lease 86400
                ntp-server 192.168.1.1
                start 192.168.1.50 {
                    stop 192.168.1.149
                }
                time-server 192.168.1.1
            }
        }
    }
    dns {
        forwarding {
            cache-size 150
            listen-on eth1
            listen-on eth2
            name-server 208.67.222.222
            name-server 208.67.220.220
            system
        }
    }
    gui {
        https-port 443
        listen-address 192.168.1.1
    }
    nat {
        rule 5010 {
            description "masquerade for WAN"
            log disable
            outbound-interface eth0
            protocol all
            type masquerade
        }
    }
    ssh {
        listen-address 192.168.1.1
        port 22
        protocol-version v2
    }
}
system {
    conntrack {
        expect-table-size 4096
        hash-size 4096
        table-size 32768
        tcp {
            half-open-connections 512
            loose enable
            max-retrans 3
        }
    }
    host-name edgemax
    ipv6 {
        disable
    }
    login {
        banner {
            post-login "Welcome to EdgeMAX - Build by Edgerouterconfig.nl"
            pre-login "\n\n\t UNAUTHORIZED USE OF THE SYSTEM\n\n\t IS PROHIBITED! \n\n "
        }
        user ubnt {
            authentication {
                encrypted-password $6$R0tERhM5JPDg$w808vSeWV1JJICgvhFGt81Vfxx6HiM3ErQ7V1nkpx1V16sPBNM01taOj60AjyXdPx493hbWugpjS8I1V/XBPW.
                plaintext-password ""
            }
            level admin
        }
    }
    name-server 208.67.222.222
    name-server 208.67.220.220
    ntp {
        server 0.ubnt.pool.ntp.org {
        }
        server 1.ubnt.pool.ntp.org {
        }
        server 2.ubnt.pool.ntp.org {
        }
        server 3.ubnt.pool.ntp.org {
        }
    }
    offload {
        ipsec enable
        ipv4 {
            forwarding enable
            pppoe enable
        }
        ipv6 {
            forwarding disable
        }
    }
    package {
        repository wheezy {
            components "main contrib non-free"
            distribution wheezy
            password ""
            url http://http.us.debian.org/debian/
            username ""
        }
        repository wheezy-updates {
            components "main contrib"
            distribution wheezy/updates
            password ""
            url http://security.debian.org/
            username ""
        }
    }
    syslog {
        global {
            facility all {
                level notice
            }
            facility protocols {
                level debug
            }
        }
    }
    time-zone UTC
}
zone-policy {
    zone DMZ {
        default-action drop
        from LAN {
            firewall {
                name LAN-DMZ
            }
        }
        from LOCAL {
            firewall {
                name LOCAL-DMZ
            }
        }
        from WAN {
            firewall {
                name WAN-DMZ
            }
        }
        interface eth2
    }
    zone LAN {
        default-action drop
        from DMZ {
            firewall {
                name DMZ-LAN
            }
        }
        from LOCAL {
            firewall {
                name LOCAL-LAN
            }
        }
        from WAN {
            firewall {
                name WAN-LAN
            }
        }
        interface eth1
    }
    zone LOCAL {
        default-action drop
        from DMZ {
            firewall {
                name DMZ-LOCAL
            }
        }
        from LAN {
            firewall {
                name LAN-LOCAL
            }
        }
        from WAN {
            firewall {
                name WAN-LOCAL
            }
        }
        local-zone
    }
    zone WAN {
        default-action drop
        from DMZ {
            firewall {
                name DMZ-WAN
            }
        }
        from LAN {
            firewall {
                name LAN-WAN
            }
        }
        from LOCAL {
            firewall {
                name LOCAL-WAN
            }
        }
        interface eth0
    }
}


/* Warning: Do not remove the following line. */
/* === vyatta-config-version: "config-management@1:conntrack@1:cron@1:dhcp-relay@1:dhcp-server@4:firewall@5:ipsec@5:nat@3:qos@1:quagga@2:system@4:ubnt-pptp@1:ubnt-util@1:vrrp@1:webgui@1:webproxy@1:zone-policy@1" === */
/* Release version: v1.8.0.4853089.160219.1607 */
