#!/bin/bash

# Only operate on the IPTV interface, ignore all others.
if [ "$interface" = "eth0.4" ]; then

    case "$reason" in

        BOUND|RENEW|REBIND|REBOOT|TIMEOUT)
            # Remove the old static route if necessary.
            if [ -n "$old_routers" ]; then
                if [ "$reason" != "RENEW" -o "$old_routers" != "$new_routers" ]; then
                    iptv_gw=${old_routers%% *} # Extract first gateway IP.
                    vtysh -c "conf t" -c "no ip route 213.75.112.0/21 $iptv_gw"
                    logger "Removed IPTV static route 213.75.112.0/21 $iptv_gw, reason $reason"
                fi
            fi

            # Create new static route if necessary.
            if [ -n "$new_routers" ]; then
                if [ "$reason" != "RENEW" -o "$old_routers" != "$new_routers" ]; then
                    iptv_gw=${new_routers%% *} # Extract first gateway IP.
                    vtysh -c "conf t" -c "ip route 213.75.112.0/21 $iptv_gw"
                    logger "Added IPTV static route 213.75.112.0/21 $iptv_gw, reason $reason"
                else
                    logger "Renewed IPTV DHCP lease, route update not needed."
                fi
            fi

            ;;

        EXPIRE|FAIL|RELEASE|STOP)
            # Remove old static route if necessary.
            if [ -n "$old_routers" ]; then
                iptv_gw=${old_routers%% *} # Extract first gateway IP.
                vtysh -c "conf t" -c "no ip route 213.75.112.0/21 $iptv_gw"
                logger "Removed IPTV static route 213.75.112.0/21 $iptv_gw, reason $reason"
            fi

            ;;

    esac

fi